<!DOCTYPE TS><TS>
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <source>error</source>
        <translation>fout</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file.</source>
        <translation>Er is een fout opgetreden bij het opslaan van het bestand.</translation>
    </message>
</context>
<context>
    <name>CFormDef</name>
    <message>
        <source>Sailcut</source>
        <translation type="obsolete">Sailcut</translation>
    </message>
    <message encoding="UTF-8">
        <source>Sail corners coordinates</source>
        <translation>Zeilhoek coördinaten</translation>
    </message>
    <message>
        <source>tack</source>
        <translation>halshoek</translation>
    </message>
    <message>
        <source>clew</source>
        <translation>halshoek</translation>
    </message>
    <message>
        <source>head</source>
        <translation>tophoek</translation>
    </message>
    <message>
        <source>peak</source>
        <translation>tophoek</translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation>IRC breedtematen</translation>
    </message>
</context>
<context>
    <name>CFormDefBase</name>
    <message>
        <source>Sail definition</source>
        <translation>Zeil definitie</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Zeil afmetingen</translation>
    </message>
    <message>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <source>Round position</source>
        <translation>Ronding positie</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Voorlijk lengte</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Onderlijk lengte</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Achterlijk lengte</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Gaffel lengte</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Achterlijk ronding</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Gaffel ronding</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Voorlijk ronding</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Onderlijk ronding</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>gr</translation>
    </message>
    <message>
        <source>Gaff angle from luff</source>
        <translation>Gaffel-mast hoek</translation>
    </message>
    <message>
        <source>Rig geometry</source>
        <translation>Tuigage geometrie</translation>
    </message>
    <message>
        <source>Fore triangle base  J</source>
        <translation>Voordriehoek basis J</translation>
    </message>
    <message>
        <source>Tack height</source>
        <translation>Halshoek hoogte</translation>
    </message>
    <message>
        <source>Distance tack to stem</source>
        <translation>Afstand halshoek-boeg</translation>
    </message>
    <message>
        <source>Main sail</source>
        <translation>Grootzeil</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Fok</translation>
    </message>
    <message>
        <source>Fore triangle hoist  I</source>
        <translation>Voordriehoek hoogte I</translation>
    </message>
    <message>
        <source>Boat length LOA</source>
        <translation>Scheepslengte LOA</translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation>Mast/Voorlijk helling</translation>
    </message>
    <message>
        <source>Cloth</source>
        <translation>Zeildoek</translation>
    </message>
    <message>
        <source>Seam width</source>
        <translation>Naad breedte</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Baan breedte</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Ontwerp</translation>
    </message>
    <message>
        <source>Mitre cut</source>
        <translation>Verstek gesneden</translation>
    </message>
    <message>
        <source>Cross cut</source>
        <translation>Schuin gesneden</translation>
    </message>
    <message>
        <source>Twist foot</source>
        <translation>Gedraaid Onderlijk</translation>
    </message>
    <message>
        <source>Horizontal cut</source>
        <translation>Horizontaal gesneden</translation>
    </message>
    <message>
        <source>Number of sections</source>
        <translation>Aantal secties</translation>
    </message>
    <message>
        <source>Number of radial gores</source>
        <translation>Aantal radiale banen</translation>
    </message>
    <message>
        <source>Radial cut</source>
        <translation>Radiaal gesneden</translation>
    </message>
    <message>
        <source>Vertical cut</source>
        <translation>Vertikaal gesneden</translation>
    </message>
    <message>
        <source>Sail shape</source>
        <translation>Zeilvorm</translation>
    </message>
    <message>
        <source>Top depth</source>
        <translation>Top bolling</translation>
    </message>
    <message>
        <source>Mid depth</source>
        <translation>Midden bolling</translation>
    </message>
    <message>
        <source>Foot depth</source>
        <translation>Onderlijk bolling</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Twist hoek</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Opheffen</translation>
    </message>
    <message>
        <source>Leech hem</source>
        <translation>Achterlijk zoom</translation>
    </message>
    <message>
        <source>Other hems</source>
        <translation>Overige zomen</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Schoothoek</translation>
    </message>
    <message encoding="UTF-8">
        <source>m²</source>
        <translation type="obsolete">m²</translation>
    </message>
    <message>
        <source>Sail area</source>
        <translation>Zeil oppervlak</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Diagonaal</translation>
    </message>
    <message>
        <source>Compute</source>
        <translation>Bereken</translation>
    </message>
    <message>
        <source>Sail ID </source>
        <translation>Zeil ID</translation>
    </message>
    <message>
        <source>Number of luff gores</source>
        <translation>Aantal voorlijk banen</translation>
    </message>
    <message>
        <source>Dihedral angle</source>
        <translation>Tweevlakshoek</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Vleugel</translation>
    </message>
    <message>
        <source>Sail identifier</source>
        <translation>Zeil ID</translation>
    </message>
    <message>
        <source>m2</source>
        <translation>m2</translation>
    </message>
</context>
<context>
    <name>CFormHelp</name>
    <message>
        <source>Sailcut CAD Handbook</source>
        <translation>Sailcut CAD Handboek</translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Openen</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Op&amp;slaan</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Opslaan &amp;Als</translation>
    </message>
    <message>
        <source>to &amp;DXF</source>
        <translation>naar &amp;DXF</translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation>naar &amp;TXT zeil</translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation>naar &amp;XML zeil</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation>&amp;Afmetingen</translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation>&amp;Vorm</translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation>&amp;Hoekverstevigingen</translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation>&amp;Tuigage</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Taal</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Sailcut</source>
        <translation>Over &amp;Sailcut</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>Beel&amp;d</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>About Sailcut</source>
        <translation>Over Sailcut</translation>
    </message>
    <message>
        <source>error</source>
        <translation>fout</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Er is een fout opgetreden bij het opslaan van het bestand</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Onlangs &amp;geopend</translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation>3D zeil e&amp;xporteren</translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation>naar &amp;Carlson plotter</translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation>Zeil&amp;banen exporteren</translation>
    </message>
    <message>
        <source>Sailcut &amp;Handbook</source>
        <translation>Sailcut &amp;Handboek</translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation>3D model</translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation>draadmodel</translation>
    </message>
    <message>
        <source>development</source>
        <translation>banen</translation>
    </message>
    <message encoding="UTF-8">
        <source>created new sail</source>
        <translation>nieuw zeil gecreëerd</translation>
    </message>
    <message>
        <source>loaded &apos;%1&apos;</source>
        <translation>&apos;%1&apos; geladen</translation>
    </message>
    <message>
        <source>error loading &apos;%1&apos;</source>
        <translation>fout bij het laden van &apos;%1&apos;</translation>
    </message>
    <message>
        <source>wrote &apos;%1&apos;</source>
        <translation>&apos;%1&apos; opgeslagen</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation>Er is een fout opgetreden bij het printen van de data</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation>Er is een fout opgetreden bij het printen van banen</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation>Er is een fout opgetreden bij het printen van het tekening</translation>
    </message>
    <message>
        <source>data</source>
        <translation>data</translation>
    </message>
    <message>
        <source>drawing</source>
        <translation>tekening</translation>
    </message>
    <message>
        <source>develop</source>
        <translation type="obsolete">banen</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>&amp;Print</translation>
    </message>
    <message>
        <source>Sailcut data sheet</source>
        <translation>Sailcut data sheet</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation>Zeil type</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation>Grootzeil</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Fok</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation>Zeilontwerp</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation>Schuin gesneden</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation>Horizontaal gesneden</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation>Radiaal gesneden</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation>Gedraaid Onderlijk</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation>Verticaal gesneden</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation>Verstek gesneden</translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation> secties,   </translation>
    </message>
    <message>
        <source> head gores.</source>
        <translation type="obsolete"> top banen.</translation>
    </message>
    <message>
        <source>Rig </source>
        <translation>Tuigage </translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation>Scheepslengte LOA</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation>Voordriehoek hoogte I</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation>Voordriehoek basis J</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation>Halshoek positie X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation>Halshoek hoogte Y</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Zeil afmetingen</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Voorlijk lengte</translation>
    </message>
    <message>
        <source>Mast rake</source>
        <translation type="obsolete">Mast helling</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation>Gaffel-mast hoek</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Gaffel lengte</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Onderlijk lengte</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Achterlijk lengte</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation>Vorm van de randen</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Voorlijk ronding</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Gaffel ronding</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Achterlijk ronding</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Onderlijk ronding</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation>Voorlijk ronding positie</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation>Gaffel ronding positie</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation>Achterlijk ronding positie</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation>Onderlijk ronding positie</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation>Zeil instellingen</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Twist hoek</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Schootlijn hoek</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation>Doek naden en zomen</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Baan breedte</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation>Naad breedte</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation>Achterlijk zoom breedte</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation>Overige zoom breedte</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Zeilvorm</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation>Voorlijk factor</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Diepte</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation>Achterlijk factor</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation>Top profiel</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation>Midden profiel bij h = </translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Onderlijk profiel</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation>Mast/Voorlijk helling</translation>
    </message>
    <message>
        <source> head gores,   </source>
        <translation> hoofd banen,   </translation>
    </message>
    <message>
        <source> luff gore.</source>
        <translation type="obsolete"> voorlijk baan.</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Vleugel</translation>
    </message>
    <message>
        <source> luff gores.</source>
        <translation> voorlijk banen.</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>gr</translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation>naar &amp;Handmatige plotgegevens</translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <source>Top profile</source>
        <translation>Top profiel</translation>
    </message>
    <message>
        <source>Middle profile</source>
        <translation>Midden profiel</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Onderlijk profiel</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Zeilvorm</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Op&amp;heffen</translation>
    </message>
    <message>
        <source>Vertical repartition</source>
        <translation>Verticale verdeling</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>Rig</source>
        <translation>Tuigage</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation>zeil &amp;definitie</translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation>3D &amp;zeil</translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation>Zeil &amp;toevoegen</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Openen</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Onlangs &amp;geopend</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Op&amp;slaan</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Opslaan &amp;Als</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>error</source>
        <translation>fout</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Er is een fout opgetreden bij het opslaan van het bestand</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation>Zeil informatie</translation>
    </message>
    <message>
        <source>file</source>
        <translation>bestand</translation>
    </message>
    <message>
        <source>name</source>
        <translation>naam</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Opnieuw laden</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Verversen</translation>
    </message>
    <message>
        <source>error</source>
        <translation>fout</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Er is een fout opgetreden bij het lezen van het bestand.</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">Dit systeem ondersteunt geen OpenGL.</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <source>Display parameters</source>
        <translation>Beeld parameters</translation>
    </message>
    <message>
        <source>elevation</source>
        <translation>hoogtehoek</translation>
    </message>
    <message>
        <source>azimuth</source>
        <translation>azimut</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controleer</translation>
    </message>
    <message>
        <source>Reset view</source>
        <translation>Beeld aanpassen</translation>
    </message>
    <message>
        <source>Labeling</source>
        <translation>Labels</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Inzoomen</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Uitzoomen</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>gr</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <source>Luff shape</source>
        <translation>Voorlijk vorm</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Diepte</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Leech shape</source>
        <translation>Achterlijk vorm</translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation>fout</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Er is een fout opgetreden bij het lezen van het bestand.</translation>
    </message>
</context>
</TS>
